data {
  int<lower=1> N;
  int<lower=1> J;
  int<lower=1> K;
  int<lower=1> C;
  array[N, J] int Y;
  array[J, K] int<lower=0, upper=1> Q;
  array[C, K] int<lower=0, upper=1> As;
}
transformed data{
  vector[C] delta;
  delta = rep_vector(1, C);
}
parameters {
  simplex[C] pi;
  simplex[3] Omega[J];
}
transformed parameters {
  vector<lower=0, upper=1>[J] prob[C];
  vector<lower=0, upper=1>[J] eta[C];
  vector<lower=0, upper=1>[J] g;
  vector<lower=0, upper=1>[J] s;
  vector[C] lp[N];
  g = to_vector(Omega[, 1]);
  s = to_vector(Omega[, 2]);
  for (c in 1:C) {
    for (j in 1:J) {
	  eta[c, j] = 1;
	  for (k in 1:K)
	    eta[c, j] = eta[c, j] * As[c, k] ^ Q[j, k];
      prob[c, j] = (1-s[j])^eta[c, j]*(g[j])^(1-eta[c, j]);
    }
  }
  for (i in 1:N) {
    for (c in 1:C) {
	  lp[i, c] = log(pi[c]);
	  for (j in 1:J)
	    lp[i, c] += bernoulli_lpmf(Y[i, j] | prob[c, j]);
	}
  }
}
model {
  for (j in 1:J) {
    Omega[j, 1] ~ beta(1, 1);
    Omega[j, 2] ~ beta(1, 1);
  }
  pi ~ dirichlet(delta);
  for (i in 1:N)
    target += log_sum_exp(lp[i, 1:C]);
}
generated quantities {
  array[N] int<lower=1, upper=C> alpha_star;
  vector<lower=0, upper=1>[J] u;
  for (i in 1:N)
    alpha_star[i] = categorical_rng(softmax(lp[i]));
  u = 1-s;
}
